@@ -1,4 +1,4 @@
-package Pcore::API::Whois v0.2.0;
+package Pcore::API::Whois v0.2.1;
 
 use Pcore -dist, -class;
 use Pcore::API::Whois::Server;
@@ -87,7 +87,7 @@ sub search ( $self, $domain, $cb = undef ) {
 
     if ( !$server_host ) {
         my $res = Pcore::API::Whois::Response->new(
-            {   query  => $query,
+            {   query => $query // $domain,
                 status => $WHOIS_NOT_SUPPORTED,
                 reason => $Pcore::API::Whois::Response::STATUS_REASON->{$WHOIS_NOT_SUPPORTED}
             }
